@@ -8,7 +8,7 @@ use Mojo::Util 'steady_time';
 use Sys::Hostname 'hostname';
 use Time::HiRes 'usleep';
 
-our $VERSION = 'v5.0.6';
+our $VERSION = 'v5.0.7';
 
 has dequeue_interval => 0.5;
 has 'sqlite';
@@ -371,10 +371,10 @@ sub stats {
       (select count(*) from minion_locks where expires > datetime('now')) as active_locks,
       (select count(distinct(worker)) from minion_jobs where state = 'active') as active_workers,
       ifnull((select seq from sqlite_sequence where name = 'minion_jobs'), 0) as enqueued_jobs,
-      (select count(*) from minion_workers) as inactive_workers,
+      (select count(*) from minion_workers) as workers,
       null as uptime}
   )->hash;
-  $stats->{inactive_workers} -= $stats->{active_workers};
+  $stats->{inactive_workers} = $stats->{workers} - $stats->{active_workers};
 
   return $stats;
 }
@@ -1226,6 +1226,12 @@ Number of workers that are currently not processing a job.
 
 Uptime in seconds. Always undefined for SQLite.
 
+=item workers
+
+  workers => 200;
+
+Number of registered workers.
+
 =back
 
 =head2 unlock
